Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(727)

Unified Diff: snapshot/cpu_context_mac.cc

Issue 628403002: Fix collision between 49c03db12965 and 56503fef865d (Closed) Base URL: https://chromium.googlesource.com/crashpad/crashpad@master
Patch Set: Created 6 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | snapshot/cpu_context_mac_test.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: snapshot/cpu_context_mac.cc
diff --git a/snapshot/cpu_context_mac.cc b/snapshot/cpu_context_mac.cc
index efd1c25d95c59dbd7507aec2a7fc8f446f023489..04b9f03dcadcc54828058e8618f1f6adc6a09e86 100644
--- a/snapshot/cpu_context_mac.cc
+++ b/snapshot/cpu_context_mac.cc
@@ -227,16 +227,16 @@ void InitializeCPUContextX86_64Thread(
void InitializeCPUContextX86_64Float(
CPUContextX86_64* context, const x86_float_state64_t* x86_float_state64) {
// This relies on both x86_float_state64_t and context->fxsave64 having
// identical (fxsave64) layout.
static_assert(offsetof(x86_float_state64_t, __fpu_reserved1) -
offsetof(x86_float_state64_t, __fpu_fcw) ==
- sizeof(context->fxsave64),
+ sizeof(context->fxsave),
"types must be equivalent");
- memcpy(&context->fxsave64,
+ memcpy(&context->fxsave,
&x86_float_state64->__fpu_fcw,
- sizeof(context->fxsave64));
+ sizeof(context->fxsave));
}
void InitializeCPUContextX86_64Debug(
« no previous file with comments | « no previous file | snapshot/cpu_context_mac_test.cc » ('j') | no next file with comments »
@@ -227,16 +227,16 @@ void InitializeCPUContextX86_64Thread(
void InitializeCPUContextX86_64Float(
CPUContextX86_64* context, const x86_float_state64_t* x86_float_state64) {
- // This relies on both x86_float_state64_t and context->fxsave64 having
- // identical (fxsave64) layout.
+ // This relies on both x86_float_state64_t and context->fxsave having
+ // identical (fxsave) layout.
static_assert(offsetof(x86_float_state64_t, __fpu_reserved1) -
offsetof(x86_float_state64_t, __fpu_fcw) ==

Powered by Google App Engine
This is Rietveld 408576698